# AI Agent Discovery Inbox
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#overview)
  * [Discovery Suggestions for AI Agents](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#discovery-suggestions-for-ai-agents)
  * [Discovery Suggestions for MCP Servers](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#discovery-suggestions-for-mcp-servers)
  * [Accessing the AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#accessing-the-ai-agent-discovery-inbox)
  * [Filtering and Searching in the Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#filtering-and-searching-in-the-discovery-inbox)
  * [Quick Filters](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#quick-filters)
  * [Linking to Suggested Fact Sheets](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#linking-to-suggested-fact-sheets)
  * [Linking Beyond Suggested Fact Sheets](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox#linking-beyond-suggested-fact-sheets)


View all
AI agents and MCP servers discovered across your enterprise landscape appear in the AI agent discovery inbox. Learn how to review, link, and reject fact sheets related to discovered items.
